==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxBaseObject_shell.h <==
#ifndef QAXBASEOBJECT_SHELL_H
#define QAXBASEOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAxBaseObject_shell : public QAxBaseObject, public QtJambiShellInterface
{
public:
    QAxBaseObject_shell(QObject* parent0 = nullptr);
    ~QAxBaseObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void resetControl() override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBaseObject_access : public QAxBaseObject
{
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
};

#endif // QAXBASEOBJECT_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiActiveX/QAxBaseObject_shell.h <==
#ifndef QAXBASEOBJECT_SHELL_H
#define QAXBASEOBJECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxobject.h>)
#include <ActiveQt/qaxobject.h>
#endif
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxBaseObject_shell : public QAxBaseObject, public QtJambiShellInterface
{
public:
    QAxBaseObject_shell(QObject* parent0 = nullptr);
    ~QAxBaseObject_shell() override;

    void childEvent(QChildEvent* event0) override;
    ulong classContext() const override;
    void connectNotify(const QMetaMethod& signal0) override;
    QString control() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void resetControl() override;
    void setClassContext(ulong classContext0) override;
    bool setControl(const QString& c0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxBaseObject_access : public QAxBaseObject
{
    jint __qt_classContext(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_control(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_resetControl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setClassContext_ulong(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint classContext0);
    jboolean __qt_setControl_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring c0);
};

#endif // defined(Q_OS_WIN)
#endif // QAXBASEOBJECT_SHELL_H
